import sys
import os
sys.path.insert(0, '../..')
from dummy_run import dummy_run
from diva_parameters import conf_dirs


def run(video,lock):
    '''
        1. SET model, using the key provide in config.yaml -> pipeline
        2. SET directory, see config.yaml -> directory
        3. CONFIGURE parameters:
            {parameters,sub_parameters,nvidia_parameters}
        4. RUN
    '''

    # 1. SET dockermodel name, must be consistent with the name in config.yaml -> pipeline
    model_name = 'diva_c3d'

    # 2. SET directory information, must be consistent with the directories in config.yaml -> directory
    VIDEO_DIR =conf_dirs.get('VIDEO_DIR')
    C3D_DIR = conf_dirs.get('C3D_DIR')
    DATA_DIR = conf_dirs.get('DATA_DIR')

    # Create output dir
    output_dir = os.sep.join([DATA_DIR, model_name, video])
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)

    # Create video list
    with open(os.sep.join([DATA_DIR, str(video) + '.lst']), 'w') as e:
        e.write(str(video) + '.avi')
    e.close()


    # 3. CONFIGURE parameters. NOTICE: It will overwrite parameters in {dockermodel}.yaml
    # NV_PARAMETER = {'NV_GPU': "'%s'" % str(gid)}
    # PARAMETER = {'-p','8000:8000'} 
    PARA_C3D = {
        '--video_dir': VIDEO_DIR,
        '--video_lst_file': os.sep.join(['/tmp', str(video) + '.lst']),
        '--out_dir': C3D_DIR
    }
    
    parameters = {
        'parameters':None,
        'nvidia_parameters':None,
        'sub_parameters' : PARA_C3D
    }
    # 4. RUN
    success = dummy_run(video,model_name,lock,parameters)
    return success

def main():
    from multiprocessing import Lock
    lock = Lock()
    video = 'MCTTR0101a.mov.deint'
    success = run(video, lock)
    print success

if __name__ == '__main__':
    main()
