import sys
import os
sys.path.insert(0, '../..')
from diva_parameters import conf_dirs
from dummy_run import dummy_run


def run(video,lock):
    '''
        1. SET model, using the key provide in config.yaml -> pipeline
        2. SET directory, see config.yaml -> directory
        3. CONFIGURE parameters:
            {parameters,sub_parameters,nvidia_parameters}
        4. RUN
    '''

    # 1. SET dockermodel name, must be consistent with the name in config.yaml -> pipeline
    model_name = 'diva_vlad'

    # 2. SET directory information, must be consistent with the directories in config.yaml -> directory
    DATA_DIR = conf_dirs.get('DATA_DIR')
    TRACK_DIR = conf_dirs.get('TRACK_DIR')
    C3D_DIR = conf_dirs.get('C3D_DIR')
    VLAD_DIR = conf_dirs.get('VLAD_DIR')

    # Create output dir
    output_dir = os.sep.join([DATA_DIR, model_name, video])
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)

    # Create video list
    # with open(os.sep.join([DATA_DIR, str(video) + '.lst']), 'w') as e:
    #     e.write(str(video) + '.avi')
    # e.close()


    # 3. CONFIGURE parameters. NOTICE: It will overwrite parameters in {dockermodel}.yaml
    # NV_PARAMETER = {'NV_GPU': "'%s'" % str(gid)}
    # PARAMETER = {'-p','8000:8000'} 
    PARA_VLAD = {
        '--track_dir':
        os.sep.join([TRACK_DIR, video, 'forward']),
        '--track_lst_file':
        os.sep.join([TRACK_DIR, video, 'forward', 'track.lst']),
        '--ft_dir':
        os.sep.join([C3D_DIR, video]),
        '--ft_lst_file':
        os.sep.join([C3D_DIR, video, 'c3d.lst']),
        '--out_dir':
        os.sep.join([VLAD_DIR, video])
    }
    parameters = {
        'parameters':None,
        'nvidia_parameters':None,
        'sub_parameters': PARA_VLAD
    }
    # 4. RUN
    success = dummy_run(video,model_name,lock,parameters)
    return success

def main():
    from multiprocessing import Pool, Lock
    lock = Lock()
    video = 'MCTTR0101a.mov.deint'
    success = run(video, lock)
    print success

if __name__ == '__main__':
    main()
